Package: statnet.common
Version: 4.13.0
Date: 2025-12-16
Title: Common R Scripts and Utilities Used by the Statnet Project
        Software
Authors@R: c(
    person(c("Pavel", "N."), "Krivitsky", role=c("aut","cre"), email="pavel@statnet.org", comment=c(ORCID="0000-0002-9101-3362", affiliation="University of New South Wales")),
    person("Skye", "Bender-deMoll", role=c("ctb"), email="skyebend@uw.edu"),
    person("Chad", "Klumb", role=c("ctb"), email="cklumb@gmail.com", comment=c(affiliation="University of Washington")),
    person("Michał", "Bojanowski", role=c("ctb"), email="michal2992@gmail.com", comment=c(ORCID="0000-0001-7503-852X")))
Description: Non-statistical utilities used by the software developed by the Statnet Project. They may also be of use to others.
Depends: R (>= 4.1)
Imports: utils, methods, coda, parallel, tools, Matrix
BugReports: https://github.com/statnet/statnet.common/issues
License: GPL-3 + file LICENSE
URL: https://statnet.org
RoxygenNote: 7.3.2.9000
Encoding: UTF-8
Suggests: covr, roxygen2, rlang (>= 1.1.1), purrr, testthat, MASS
NeedsCompilation: yes
Packaged: 2025-12-16 11:40:25 UTC; pavel
Author: Pavel N. Krivitsky [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9101-3362>, affiliation: University of
    New South Wales),
  Skye Bender-deMoll [ctb],
  Chad Klumb [ctb] (affiliation: University of Washington),
  Michał Bojanowski [ctb] (ORCID:
    <https://orcid.org/0000-0001-7503-852X>)
Maintainer: Pavel N. Krivitsky <pavel@statnet.org>
Repository: CRAN
Date/Publication: 2025-12-16 18:10:10 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-25 13:28:15 UTC; unix
Archs: statnet.common.so.dSYM
