# Generated by roxygen2: do not edit by hand

S3method("$",control.list)
S3method("[",term_list)
S3method("[",wmatrix)
S3method("[<-",wmatrix)
S3method("envir<-",default)
S3method("envir<-",term_list)
S3method("lrowweights<-",linwmatrix)
S3method("lrowweights<-",logwmatrix)
S3method("lrowweights<-",matrix)
S3method("rowweights<-",linwmatrix)
S3method("rowweights<-",logwmatrix)
S3method("rowweights<-",matrix)
S3method("sign<-",term_list)
S3method(as.control.list,control.list)
S3method(as.control.list,list)
S3method(as.linwmatrix,linwmatrix)
S3method(as.linwmatrix,logwmatrix)
S3method(as.linwmatrix,matrix)
S3method(as.logwmatrix,linwmatrix)
S3method(as.logwmatrix,logwmatrix)
S3method(as.logwmatrix,matrix)
S3method(as.term_list,default)
S3method(as.term_list,term_list)
S3method(c,term_list)
S3method(compress_rows,data.frame)
S3method(compress_rows,linwmatrix)
S3method(compress_rows,logwmatrix)
S3method(decompress_rows,compressed_rows_df)
S3method(decompress_rows,wmatrix)
S3method(diff,control.list)
S3method(envir,default)
S3method(envir,term_list)
S3method(lrowweights,linwmatrix)
S3method(lrowweights,logwmatrix)
S3method(order,data.frame)
S3method(order,default)
S3method(order,matrix)
S3method(print,control.list)
S3method(print,diff.control.list)
S3method(print,linwmatrix)
S3method(print,logwmatrix)
S3method(print,term_list)
S3method(print,wmatrix)
S3method(rowweights,linwmatrix)
S3method(rowweights,logwmatrix)
S3method(sign,term_list)
S3method(sort,data.frame)
S3method(split,array)
S3method(split,matrix)
S3method(trim_env,default)
S3method(trim_env,environment)
S3method(update,Welford)
export("EVL<-")
export("NVL<-")
export("envir<-")
export("lrowweights<-")
export("replace<-")
export("rowweights<-")
export("sign<-")
export("ult<-")
export(.Deprecate_method)
export(.Deprecate_once)
export(COLLATE_ALL_MY_CONTROLS_EXPR)
export(ERRVL)
export(ERRVL2)
export(ERRVL3)
export(EVL)
export(EVL2)
export(EVL3)
export(NVL)
export(NVL2)
export(NVL3)
export(UPDATE_MY_SCTRL_EXPR)
export(Welford)
export(all_identical)
export(append.rhs.formula)
export(append_rhs.formula)
export(arr_from_coo)
export(arr_to_coo)
export(as.control.list)
export(as.linwmatrix)
export(as.logwmatrix)
export(as.term_list)
export(attr)
export(base_env)
export(check.control.class)
export(colMeans.mcmc.list)
export(collate_controls)
export(compress_rows)
export(control.remap)
export(deInf)
export(decompress_rows)
export(default_options)
export(despace)
export(empty_env)
export(enlist)
export(envir)
export(eval_lhs.formula)
export(filter_rhs.formula)
export(fixed.pval)
export(forkTimeout)
export(ginv_eigen)
export(handle.controls)
export(is.SPD)
export(is.linwmatrix)
export(is.logwmatrix)
export(is.wmatrix)
export(lapply.mcmc.list)
export(linwmatrix)
export(list_rhs.formula)
export(list_summands.call)
export(locate_function)
export(locate_prefixed_function)
export(log1mexp)
export(log_mean_exp)
export(log_sum_exp)
export(logwmatrix)
export(lrowweights)
export(lweighted.cov)
export(lweighted.mean)
export(lweighted.var)
export(match_names)
export(message_print)
export(modify_in_place)
export(nonsimp.update.formula)
export(nonsimp_update.formula)
export(once)
export(opttest)
export(order)
export(paste.and)
export(persistEval)
export(persistEvalQ)
export(qrsolve)
export(qrssolve)
export(replace)
export(rowweights)
export(sandwich_ginv)
export(sandwich_qrsolve)
export(sandwich_qrssolve)
export(sandwich_sginv)
export(sandwich_solve)
export(sandwich_ssolve)
export(set.control.class)
export(set_diag)
export(sginv)
export(simplify_simple)
export(skip_if_not_checking)
export(snctrl)
export(snctrl_names)
export(snearPD)
export(split_len)
export(srcond)
export(ssolve)
export(statnet.cite.foot)
export(statnet.cite.head)
export(statnet.cite.pkg)
export(statnetStartupMessage)
export(sweep.mcmc.list)
export(sweep_cols.matrix)
export(term.list.formula)
export(term_list)
export(trim_env)
export(ult)
export(unused_dots_warning)
export(unwhich)
export(update_snctrl)
export(var.mcmc.list)
export(vector.namesmatch)
export(which_top_n)
export(xAxT)
export(xTAx)
export(xTAx_eigen)
export(xTAx_qrsolve)
export(xTAx_qrssolve)
export(xTAx_seigen)
export(xTAx_solve)
export(xTAx_ssolve)
importFrom(coda,as.mcmc)
importFrom(coda,as.mcmc.list)
importFrom(methods,is)
importFrom(stats,as.formula)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,getAnywhere)
importFrom(utils,modifyList)
useDynLib(statnet.common)
